@@ -1,4 +1,4 @@
-from typing import Any, Dict, Generator, Union
+from typing import Any, Dict, Generator
 
 import requests
 from requests import RequestException
@@ -6,11 +6,12 @@ from urllib3.exceptions import NewConnectionError
 
 from ..__version__ import __version__
 from ..client.response import Response
+from ..type_checked import type_checked
 from .base_sync_client import BaseSyncClient
 
-USER_AGENT = f"py-stellar-sdk/{__version__}/SimpleRequestsClient"
+USER_AGENT = f"py-stellar-base/{__version__}/SimpleRequestsClient"
 HEADERS = {
-    "X-Client-Name": "py-stellar-sdk",
+    "X-Client-Name": "py-stellar-base",
     "X-Client-Version": __version__,
     "User-Agent": USER_AGENT,
 }
@@ -18,6 +19,7 @@ HEADERS = {
 __all__ = ["SimpleRequestsClient"]
 
 
+@type_checked
 class SimpleRequestsClient(BaseSyncClient):
     """The :class:`SimpleRequestsClient` object is a synchronous http client,
     which represents the interface for making requests to a server instance.
