@@ -2,10 +2,7 @@ from json import JSONDecodeError
 from typing import Optional
 
 from .client.response import Response
-
-BuildInValueError = ValueError
-BuildInTypeError = TypeError
-BuildInAttributeError = AttributeError
+from .type_checked import type_checked
 
 __all__ = [
     "SdkError",
@@ -35,51 +32,45 @@ __all__ = [
 ]
 
 
+# The following is kept for compatibility
+ValueError = ValueError
+TypeError = TypeError
+AttributeError = AttributeError
+
+
 class SdkError(Exception):
     """Base exception for all stellar sdk related errors"""
 
 
-class ValueError(BuildInValueError, SdkError):
-    """exception for all values related errors"""
-
-
-class TypeError(BuildInTypeError, SdkError):
-    """exception for all type related errors"""
-
-
-class AttributeError(BuildInAttributeError, SdkError):
-    """Attribute not found."""
-
-
-class BadSignatureError(ValueError):
+class BadSignatureError(SdkError, ValueError):
     """Raised when the signature was forged or otherwise corrupt."""
 
 
-class Ed25519PublicKeyInvalidError(ValueError):
+class Ed25519PublicKeyInvalidError(SdkError, ValueError):
     """Ed25519 public key is incorrect."""
 
 
-class Ed25519SecretSeedInvalidError(ValueError):
+class Ed25519SecretSeedInvalidError(SdkError, ValueError):
     """Ed25519 secret seed is incorrect."""
 
 
-class MissingEd25519SecretSeedError(ValueError):
+class MissingEd25519SecretSeedError(SdkError, ValueError):
     """Missing Ed25519 secret seed in the keypair"""
 
 
-class MuxedEd25519AccountInvalidError(ValueError):
+class MuxedEd25519AccountInvalidError(SdkError, ValueError):
     """Muxed Ed25519 public key is incorrect."""
 
 
-class MemoInvalidException(ValueError):
+class MemoInvalidException(SdkError, ValueError):
     """Memo is incorrect."""
 
 
-class AssetCodeInvalidError(ValueError):
+class AssetCodeInvalidError(SdkError, ValueError):
     """Asset Code is incorrect."""
 
 
-class AssetIssuerInvalidError(ValueError):
+class AssetIssuerInvalidError(SdkError, ValueError):
     """Asset issuer is incorrect."""
 
 
@@ -87,7 +78,7 @@ class NoApproximationError(SdkError):
     """Approximation cannot be found"""
 
 
-class SignatureExistError(ValueError):
+class SignatureExistError(SdkError, ValueError):
     """A keypair can only sign a transaction once."""
 
 
@@ -181,6 +172,7 @@ class FeatureNotEnabledError(SdkError):
     """The feature is not enabled."""
 
 
+@type_checked
 def raise_request_exception(response: Response) -> None:
     status_code = response.status_code
     if status_code == 200:
