@@ -2,11 +2,13 @@ from typing import Optional, Union
 
 from .. import xdr as stellar_xdr
 from ..muxed_account import MuxedAccount
+from ..type_checked import type_checked
 from .operation import Operation
 
 __all__ = ["AccountMerge"]
 
 
+@type_checked
 class AccountMerge(Operation):
     """The :class:`AccountMerge` object, which represents a
     AccountMerge operation on Stellar's network.
@@ -16,8 +18,10 @@ class AccountMerge(Operation):
 
     Threshold: High
 
+    See `Account Merge <https://developers.stellar.org/docs/start/list-of-operations/#account-merge>`_ for more information.
+
     :param destination: Destination to merge the source account into.
-    :param source: The source account (defaults to transaction source).
+    :param source: The source account for the operation. Defaults to the transaction's source account.
 
     """
 
