@@ -5,12 +5,14 @@ from .. import xdr as stellar_xdr
 from ..keypair import Keypair
 from ..muxed_account import MuxedAccount
 from ..strkey import StrKey
+from ..type_checked import type_checked
+from ..utils import raise_if_not_valid_amount, raise_if_not_valid_ed25519_public_key
 from .operation import Operation
-from .utils import check_amount, check_ed25519_public_key
 
 __all__ = ["CreateAccount"]
 
 
+@type_checked
 class CreateAccount(Operation):
     """The :class:`CreateAccount` object, which represents a Create Account
     operation on Stellar's network.
@@ -20,11 +22,13 @@ class CreateAccount(Operation):
 
     Threshold: Medium
 
+    See `Create Account <https://developers.stellar.org/docs/start/list-of-operations/#create-account>`_ for more information.
+
     :param destination: Destination account ID to create an account for.
     :param starting_balance: Amount in XLM the account should be
         funded for. Must be greater than the `reserve balance amount
-        <https://www.stellar.org/developers/learn/concepts/fees.html>`_.
-    :param source: The source account for the payment. Defaults to the
+        <https://developers.stellar.org/docs/glossary/minimum-balance/>`_.
+    :param source: The source account for the operation. Defaults to the
         transaction's source account.
 
     """
@@ -40,10 +44,10 @@ class CreateAccount(Operation):
         source: Optional[Union[MuxedAccount, str]] = None,
     ) -> None:
         super().__init__(source)
-        check_ed25519_public_key(destination)
-        check_amount(starting_balance)
         self.destination: str = destination
-        self.starting_balance: Union[str, Decimal] = starting_balance
+        self.starting_balance: str = str(starting_balance)
+        raise_if_not_valid_ed25519_public_key(self.destination, "destination")
+        raise_if_not_valid_amount(self.starting_balance, "starting_balance")
 
     def _to_operation_body(self) -> stellar_xdr.OperationBody:
         destination = Keypair.from_public_key(self.destination).xdr_account_id()
