@@ -2,24 +2,25 @@ from typing import Optional, Union
 
 from .. import xdr as stellar_xdr
 from ..muxed_account import MuxedAccount
+from ..type_checked import type_checked
 from .operation import Operation
 
 __all__ = ["EndSponsoringFutureReserves"]
 
 
+@type_checked
 class EndSponsoringFutureReserves(Operation):
     """The :class:`EndSponsoringFutureReserves` object, which represents a EndSponsoringFutureReserves
     operation on Stellar's network.
 
     Terminates the current is-sponsoring-future-reserves-for relationship in which the source account is sponsored.
-    See `Sponsored Reserves <https://developers.stellar.org/docs/glossary/sponsored-reserves/>_` for more information.
-
-    See `End Sponsoring Future Reserves
-    <https://developers.stellar.org/docs/start/list-of-operations/#end-sponsoring-future-reserves>_`.
+    See `Sponsored Reserves <https://developers.stellar.org/docs/glossary/sponsored-reserves/>`_ for more information.
 
     Threshold: Medium
 
-    :param source: The source account (defaults to transaction source).
+    See `End Sponsoring Future Reserves <https://developers.stellar.org/docs/start/list-of-operations/#end-sponsoring-future-reserves>`_.
+
+    :param source: The source account for the operation. Defaults to the transaction's source account.
     """
 
     _XDR_OPERATION_TYPE: stellar_xdr.OperationType = (
