@@ -5,34 +5,38 @@ from .. import xdr as stellar_xdr
 from ..asset import Asset
 from ..muxed_account import MuxedAccount
 from ..price import Price
+from ..type_checked import type_checked
+from ..utils import raise_if_not_valid_amount
 from .operation import Operation
-from .utils import check_amount, check_price
 
 __all__ = ["ManageBuyOffer"]
 
 
+@type_checked
 class ManageBuyOffer(Operation):
     """The :class:`ManageBuyOffer` object, which represents a ManageBuyOffer
     operation on Stellar's network.
 
     Creates, updates, or deletes an buy offer.
 
-    If you want to create a new offer set Offer ID to 0.
+    If you want to create a new offer set `offer_id` to ``0``.
 
-    If you want to update an existing offer set Offer ID to existing offer ID.
+    If you want to update an existing offer set `offer_id` to existing offer ID.
 
-    If you want to delete an existing offer set Offer ID to existing offer ID
-    and set Amount to 0.
+    If you want to delete an existing offer set `offer_id` to existing offer ID
+    and set `amount` to ``0``.
 
     Threshold: Medium
 
+    See `Manage Buy Offer <https://developers.stellar.org/docs/start/list-of-operations/#manage-buy-offer>`_ for more information.
+
     :param selling: What you're selling.
     :param buying: What you're buying.
-    :param amount: Amount being bought. if set to 0, delete the offer.
+    :param amount: Amount being bought. if set to ``0``, delete the offer.
     :param price: Price of thing being bought in terms of what you are selling.
-    :param offer_id: If `0`, will create a new offer (default). Otherwise,
+    :param offer_id: If ``0``, will create a new offer (default). Otherwise,
         edits an existing offer.
-    :param source: The source account (defaults to transaction source).
+    :param source: The source account for the operation. Defaults to the transaction's source account.
 
     """
 
@@ -50,24 +54,19 @@ class ManageBuyOffer(Operation):
         source: Optional[Union[MuxedAccount, str]] = None,
     ) -> None:
         super().__init__(source)
-        check_amount(amount)
-        check_price(price)
+        if not isinstance(price, Price):
+            price = Price.from_raw_price(price)
         self.selling: Asset = selling
         self.buying: Asset = buying
-        self.amount: Union[str, Decimal] = amount
-        self.price: Union[Price, str, Decimal] = price
+        self.amount: str = str(amount)
+        self.price: Price = price
         self.offer_id: int = offer_id
+        raise_if_not_valid_amount(self.amount, "amount")
 
     def _to_operation_body(self) -> stellar_xdr.OperationBody:
         selling = self.selling.to_xdr_object()
         buying = self.buying.to_xdr_object()
-
-        if isinstance(self.price, Price):
-            price_fraction = self.price
-        else:
-            price_fraction = Price.from_raw_price(self.price)
-
-        price = price_fraction.to_xdr_object()
+        price = self.price.to_xdr_object()
         amount = stellar_xdr.Int64(Operation.to_xdr_amount(self.amount))
         manage_buy_offer_op = stellar_xdr.ManageBuyOfferOp(
             selling, buying, amount, price, stellar_xdr.Int64(self.offer_id)
