@@ -4,12 +4,14 @@ from typing import List, Optional, Union
 from .. import xdr as stellar_xdr
 from ..asset import Asset
 from ..muxed_account import MuxedAccount
+from ..type_checked import type_checked
+from ..utils import raise_if_not_valid_amount
 from .operation import Operation
-from .utils import check_amount
 
 __all__ = ["PathPaymentStrictSend"]
 
 
+@type_checked
 class PathPaymentStrictSend(Operation):
     """The :class:`PathPaymentStrictSend` object, which represents a PathPaymentStrictSend
     operation on Stellar's network.
@@ -20,13 +22,15 @@ class PathPaymentStrictSend(Operation):
 
     Threshold: Medium
 
+    See `Path Payment Strict Send <https://developers.stellar.org/docs/start/list-of-operations/#path-payment-strict-send>`_ for more information.
+
     :param destination: The destination account to send to.
-    :param send_asset: The asset to pay with.
-    :param send_amount: Amount of send_asset to send.
-    :param dest_asset: The asset the destination will receive.
-    :param dest_min: The minimum amount of dest_asset to be received.
+    :param send_asset: The `asset` to pay with.
+    :param send_amount: Amount of `send_asset` to send.
+    :param dest_asset: The asset the `destination` will receive.
+    :param dest_min: The minimum amount of `dest_asset` to be received.
     :param path: A list of Asset objects to use as the path.
-    :param source: The source account for the payment. Defaults to the
+    :param source: The source account for the operation. Defaults to the
         transaction's source account.
     """
 
@@ -45,16 +49,16 @@ class PathPaymentStrictSend(Operation):
         source: Optional[Union[MuxedAccount, str]] = None,
     ) -> None:
         super().__init__(source)
-        check_amount(send_amount)
-        check_amount(dest_min)
         if isinstance(destination, str):
             destination = MuxedAccount.from_account(destination)
         self.destination: MuxedAccount = destination
         self.send_asset: Asset = send_asset
-        self.send_amount: Union[str, Decimal] = send_amount
+        self.send_amount: str = str(send_amount)
         self.dest_asset: Asset = dest_asset
-        self.dest_min: Union[str, Decimal] = dest_min
+        self.dest_min: str = str(dest_min)
         self.path: List[Asset] = path  # a list of paths/assets
+        raise_if_not_valid_amount(self.send_amount, "send_amount")
+        raise_if_not_valid_amount(self.dest_min, "dest_min")
 
     def _to_operation_body(self) -> stellar_xdr.OperationBody:
         destination = self.destination.to_xdr_object()
