@@ -4,12 +4,14 @@ from typing import Optional, Union
 from .. import xdr as stellar_xdr
 from ..asset import Asset
 from ..muxed_account import MuxedAccount
+from ..type_checked import type_checked
+from ..utils import raise_if_not_valid_amount
 from .operation import Operation
-from .utils import check_amount
 
 __all__ = ["Payment"]
 
 
+@type_checked
 class Payment(Operation):
     """The :class:`Payment` object, which represents a Payment operation on
     Stellar's network.
@@ -18,10 +20,12 @@ class Payment(Operation):
 
     Threshold: Medium
 
+    See `Payment <https://developers.stellar.org/docs/start/list-of-operations/#payment>`_ for more information.
+
     :param destination: The destination account ID.
     :param asset: The asset to send.
     :param amount: The amount to send.
-    :param source: The source account for the payment. Defaults to the
+    :param source: The source account for the operation. Defaults to the
         transaction's source account.
 
     """
@@ -36,12 +40,12 @@ class Payment(Operation):
         source: Optional[Union[MuxedAccount, str]] = None,
     ) -> None:
         super().__init__(source)
-        check_amount(amount)
         if isinstance(destination, str):
             destination = MuxedAccount.from_account(destination)
         self.destination: MuxedAccount = destination
         self.asset: Asset = asset
-        self.amount: Union[str, Decimal] = amount
+        self.amount: str = str(amount)
+        raise_if_not_valid_amount(self.amount, "amount")
 
     def _to_operation_body(self) -> stellar_xdr.OperationBody:
         asset = self.asset.to_xdr_object()
