@@ -1,3 +1,4 @@
+import warnings
 from enum import IntFlag
 from typing import Optional, Union
 
@@ -6,16 +7,16 @@ from ..keypair import Keypair
 from ..muxed_account import MuxedAccount
 from ..signer import Signer
 from ..strkey import StrKey
+from ..type_checked import type_checked
+from ..utils import raise_if_not_valid_ed25519_public_key
 from .operation import Operation
-from .utils import check_ed25519_public_key
 
 __all__ = ["AuthorizationFlag", "SetOptions"]
 
 
 class AuthorizationFlag(IntFlag):
     """Indicates which flags to set. For details about the flags,
-    please refer to the `accounts doc <https://www.stellar.org/developers/guides/concepts/accounts.html>`_.
-    The bit mask integer adds onto the existing flags of the account.
+    please refer to the `Control Access to an Asset - Flag <https://developers.stellar.org/docs/issuing-assets/control-asset-access/#flags>`__.
     """
 
     AUTHORIZATION_REQUIRED = 1
@@ -24,6 +25,7 @@ class AuthorizationFlag(IntFlag):
     AUTHORIZATION_CLAWBACK_ENABLED = 8
 
 
+@type_checked
 class SetOptions(Operation):
     """The :class:`SetOptions` object, which represents a SetOptions operation
     on Stellar's network.
@@ -31,44 +33,50 @@ class SetOptions(Operation):
     This operation sets the options for an account.
 
     For more information on the signing options, please refer to the `multi-sig
-    doc <https://www.stellar.org/developers/guides/concepts/multi-sig.html>`_.
+    doc <https://developers.stellar.org/docs/glossary/multisig/>`_.
 
     When updating signers or other thresholds, the threshold of this operation
     is high.
 
     Threshold: Medium or High
 
+    See `Set Options <https://developers.stellar.org/docs/start/list-of-operations/#set-options>`_ for more information.
+
     :param inflation_dest: Account of the inflation destination.
     :param clear_flags: Indicates which flags to clear. For details about the flags,
-        please refer to the `accounts doc <https://www.stellar.org/developers/guides/concepts/accounts.html>`_.
+        please refer to the `Control Access to an Asset - Flag <https://developers.stellar.org/docs/issuing-assets/control-asset-access/#flags>`__.
         The `bit mask <https://en.wikipedia.org/wiki/Bit_field>`_ integer subtracts from the existing flags of the account.
         This allows for setting specific bits without knowledge of existing flags, you can also use
         :class:`stellar_sdk.operation.set_options.AuthorizationFlag`
-        - AUTHORIZATION_REQUIRED = 1
-        - AUTHORIZATION_REVOCABLE = 2
-        - AUTHORIZATION_IMMUTABLE = 4
-        - AUTHORIZATION_CLAWBACK_ENABLED = 8
+
+        * AUTHORIZATION_REQUIRED = 1
+        * AUTHORIZATION_REVOCABLE = 2
+        * AUTHORIZATION_IMMUTABLE = 4
+        * AUTHORIZATION_CLAWBACK_ENABLED = 8
+
     :param set_flags: Indicates which flags to set. For details about the flags,
-        please refer to the `accounts doc <https://www.stellar.org/developers/guides/concepts/accounts.html>`_.
+        please refer to the `Control Access to an Asset - Flag <https://developers.stellar.org/docs/issuing-assets/control-asset-access/#flags>`__.
         The bit mask integer adds onto the existing flags of the account.
         This allows for setting specific bits without knowledge of existing flags, you can also use
         :class:`stellar_sdk.operation.set_options.AuthorizationFlag`
-        - AUTHORIZATION_REQUIRED = 1
-        - AUTHORIZATION_REVOCABLE = 2
-        - AUTHORIZATION_IMMUTABLE = 4
-        - AUTHORIZATION_CLAWBACK_ENABLED = 8
+
+        * AUTHORIZATION_REQUIRED = 1
+        * AUTHORIZATION_REVOCABLE = 2
+        * AUTHORIZATION_IMMUTABLE = 4
+        * AUTHORIZATION_CLAWBACK_ENABLED = 8
+
     :param master_weight: A number from 0-255 (inclusive) representing the weight of the master key.
         If the weight of the master key is updated to 0, it is effectively disabled.
     :param low_threshold: A number from 0-255 (inclusive) representing the threshold this account sets on all
-        operations it performs that have `a low threshold <https://www.stellar.org/developers/guides/concepts/multi-sig.html>`_.
+        operations it performs that have `a low threshold <https://developers.stellar.org/docs/glossary/multisig/>`_.
     :param med_threshold: A number from 0-255 (inclusive) representing the threshold this account sets on all
-        operations it performs that have `a medium threshold <https://www.stellar.org/developers/guides/concepts/multi-sig.html>`_.
+        operations it performs that have `a medium threshold <https://developers.stellar.org/docs/glossary/multisig/>`_.
     :param high_threshold: A number from 0-255 (inclusive) representing the threshold this account sets on all
-        operations it performs that have `a high threshold <https://www.stellar.org/developers/guides/concepts/multi-sig.html>`_.
+        operations it performs that have `a high threshold <https://developers.stellar.org/docs/glossary/multisig/>`_.
     :param home_domain: sets the home domain used for
-        reverse `federation <https://www.stellar.org/developers/guides/concepts/federation.html>`_ lookup.
+        reverse `federation <https://developers.stellar.org/docs/glossary/federation/>`_ lookup.
     :param signer: Add, update, or remove a signer from the account.
-    :param source: The source account (defaults to transaction source).
+    :param source: The source account for the operation. Defaults to the transaction's source account.
 
     """
 
@@ -90,24 +98,31 @@ class SetOptions(Operation):
         source: Optional[Union[MuxedAccount, str]] = None,
     ) -> None:
         super().__init__(source)
-        if inflation_dest is not None:
-            check_ed25519_public_key(inflation_dest)
+        if set_flags is not None and not isinstance(set_flags, AuthorizationFlag):
+            warnings.warn(
+                "`set_flags` is a int, we recommend using AuthorizationFlag.",
+                DeprecationWarning,
+            )
+            set_flags = AuthorizationFlag(set_flags)
 
-        if isinstance(set_flags, AuthorizationFlag):
-            set_flags = set_flags.value
-
-        if isinstance(clear_flags, AuthorizationFlag):
-            clear_flags = clear_flags.value
+        if clear_flags is not None and not isinstance(clear_flags, AuthorizationFlag):
+            warnings.warn(
+                "`clear_flags` is a int, we recommend using AuthorizationFlag.",
+                DeprecationWarning,
+            )
+            clear_flags = AuthorizationFlag(clear_flags)
 
         self.inflation_dest = inflation_dest
-        self.clear_flags: int = clear_flags  # type: ignore[assignment]
-        self.set_flags: int = set_flags  # type: ignore[assignment]
-        self.master_weight = master_weight
-        self.low_threshold = low_threshold
-        self.med_threshold = med_threshold
-        self.high_threshold = high_threshold
-        self.home_domain = home_domain
+        self.clear_flags: Optional[AuthorizationFlag] = clear_flags
+        self.set_flags: Optional[AuthorizationFlag] = set_flags
+        self.master_weight: Optional[int] = master_weight
+        self.low_threshold: Optional[int] = low_threshold
+        self.med_threshold: Optional[int] = med_threshold
+        self.high_threshold: Optional[int] = high_threshold
+        self.home_domain: Optional[str] = home_domain
         self.signer: Optional[Signer] = signer
+        if self.inflation_dest is not None:
+            raise_if_not_valid_ed25519_public_key(self.inflation_dest, "inflation_dest")
 
     def _to_operation_body(self) -> stellar_xdr.OperationBody:
         inflation_dest = (
@@ -121,10 +136,12 @@ class SetOptions(Operation):
             else None
         )
         clear_flags = (
-            None if self.clear_flags is None else stellar_xdr.Uint32(self.clear_flags)
+            None
+            if self.clear_flags is None
+            else stellar_xdr.Uint32(self.clear_flags.value)
         )
         set_flags = (
-            None if self.set_flags is None else stellar_xdr.Uint32(self.set_flags)
+            None if self.set_flags is None else stellar_xdr.Uint32(self.set_flags.value)
         )
         master_weight = (
             None
