@@ -19,13 +19,14 @@ from ..fee_bump_transaction_envelope import FeeBumpTransactionEnvelope
 from ..keypair import Keypair
 from ..memo import HashMemo, IdMemo, Memo, NoneMemo, ReturnHashMemo, TextMemo
 from ..transaction_envelope import TransactionEnvelope
-from ..utils import is_fee_bump_transaction
+from ..type_checked import type_checked
 
 __all__ = ["PayStellarUri", "TransactionStellarUri", "Replacement"]
 
 STELLAR_SCHEME: str = "web+stellar"
 
 
+@type_checked
 class StellarUri(object, metaclass=abc.ABCMeta):
     def __init__(self, signature: Optional[str] = None):
         self.signature = signature
@@ -67,6 +68,7 @@ class StellarUri(object, metaclass=abc.ABCMeta):
         return callback[4:]
 
 
+@type_checked
 class PayStellarUri(StellarUri):
     """A request for a payment to be signed.
 
@@ -251,7 +253,7 @@ class PayStellarUri(StellarUri):
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return (
             self.destination == other.destination
             and self.amount == other.amount
@@ -267,24 +269,27 @@ class PayStellarUri(StellarUri):
         )
 
 
+@type_checked
 class Replacement:
+    """Used to represent a single replacement.
+
+    An example::
+
+        r1 = Replacement("sourceAccount", "X", "account on which to create the trustline")
+        r2 = Replacement("seqNum", "Y", "sequence for sourceAccount")
+        replacements = [r1, r2]
+
+    See `SEP-0007 <https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0007.md#operation-tx>`__
+
+    :param txrep_tx_field_name: Txrep tx field name.
+    :param reference_identifier: Reference identifier.
+    :param hint: A brief and clear explanation of the context for the `reference_identifier`.
+
+    """
+
     def __init__(
         self, txrep_tx_field_name: str, reference_identifier: str, hint: str
     ) -> None:
-        """Used to represent a single replacement.
-
-        Example:
-            >>> r1 = Replacement("sourceAccount", "X", "account on which to create the trustline")
-            >>> r2 = Replacement("seqNum", "Y", "sequence for sourceAccount")
-            >>> replacements = [r1, r2]
-
-        See `SEP-0007 <https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0007.md#operation-tx>`_
-
-        :param txrep_tx_field_name: Txrep tx field name.
-        :param reference_identifier: Reference identifier.
-        :param hint: A brief and clear explanation of the context for the `reference_identifier`.
-
-        """
         self.txrep_tx_field_name = txrep_tx_field_name
         self.reference_identifier = reference_identifier
         self.hint = hint
@@ -298,7 +303,7 @@ class Replacement:
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return (
             self.txrep_tx_field_name == other.txrep_tx_field_name
             and self.reference_identifier == other.reference_identifier
@@ -306,10 +311,11 @@ class Replacement:
         )
 
 
+@type_checked
 class TransactionStellarUri(StellarUri):
     """A request for a transaction to be signed.
 
-    See `SEP-0007 <https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0007.md#operation-tx>`_
+    See `SEP-0007 <https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0007.md#operation-tx>`__
 
     :param transaction_envelope: Transaction waiting to be signed.
     :param replace: A value that identifies the fields to be replaced in the xdr using the Txrep (SEP-0011) representation.
@@ -426,7 +432,7 @@ class TransactionStellarUri(StellarUri):
         signature = query.get("signature")
         if xdr is None:
             raise ValueError("`xdr` is missing from uri.")
-        if is_fee_bump_transaction(xdr):
+        if FeeBumpTransactionEnvelope.is_fee_bump_transaction_envelope(xdr):
             tx = FeeBumpTransactionEnvelope.from_xdr(xdr, network_passphrase)
         else:
             tx = TransactionEnvelope.from_xdr(xdr, network_passphrase)  # type: ignore[assignment]
@@ -466,7 +472,7 @@ class TransactionStellarUri(StellarUri):
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, self.__class__):
-            return NotImplemented  # pragma: no cover
+            return NotImplemented
         return (
             self.transaction_envelope == other.transaction_envelope
             and self.replace == other.replace
