@@ -33,7 +33,7 @@ class TimeBounds:
             raise ValueError("max_time cannot be negative.")
 
         if 0 < max_time < min_time:
-            raise ValueError("max_time must be >= min_time.")
+            raise ValueError("min_time cannot be greater than max_time.")
 
         self.min_time: int = min_time
         self.max_time: int = max_time
