@@ -4,9 +4,9 @@ from typing import Callable, overload
 from typeguard import T_CallableOrType
 from typeguard import typechecked as _typechecked
 
-_STELLAR_SDK_ENFORCE_TYPE_CHECK_FLAG: str = "STELLAR_SDK_ENFORCE_TYPE_CHECK"
-_STELLAR_SDK_ENFORCE_TYPE_CHECK: bool = os.getenv(
-    _STELLAR_SDK_ENFORCE_TYPE_CHECK_FLAG, "False"
+_STELLAR_SDK_RUNTIME_TYPE_CHECKING_FLAG: str = "STELLAR_SDK_RUNTIME_TYPE_CHECKING"
+_STELLAR_SDK_RUNTIME_TYPE_CHECKING: bool = os.getenv(
+    _STELLAR_SDK_RUNTIME_TYPE_CHECKING_FLAG, "True"
 ).lower() in ("true", "1", "t")
 
 
@@ -23,4 +23,7 @@ def type_checked(func: T_CallableOrType) -> T_CallableOrType:
 def type_checked(
     func=None,
 ):
-    return _typechecked(func=func, always=_STELLAR_SDK_ENFORCE_TYPE_CHECK)
+    if _STELLAR_SDK_RUNTIME_TYPE_CHECKING:
+        return _typechecked(func=func)
+    else:
+        return func
