@@ -1,11 +1,10 @@
 from xdrlib import Packer, Unpacker
 
-from ..exceptions import ValueError
-from ..type_checked import type_checked
-
 __all__ = [
     "Integer",
     "UnsignedInteger",
+    "Float",
+    "Double",
     "Hyper",
     "UnsignedHyper",
     "Boolean",
@@ -14,7 +13,6 @@ __all__ = [
 ]
 
 
-@type_checked
 class Integer:
     def __init__(self, value: int) -> None:
         self.value = value
@@ -23,7 +21,7 @@ class Integer:
         packer.pack_int(self.value)
 
     @staticmethod
-    def unpack(unpacker: Unpacker) -> "int":
+    def unpack(unpacker: Unpacker) -> int:
         return unpacker.unpack_int()
 
     def __eq__(self, other: object) -> bool:
@@ -35,7 +33,6 @@ class Integer:
         return f"<Integer [value={self.value}]>"
 
 
-@type_checked
 class UnsignedInteger:
     def __init__(self, value: int) -> None:
         self.value = value
@@ -44,7 +41,7 @@ class UnsignedInteger:
         packer.pack_uint(self.value)
 
     @staticmethod
-    def unpack(unpacker: Unpacker) -> "int":
+    def unpack(unpacker: Unpacker) -> int:
         return unpacker.unpack_uint()
 
     def __eq__(self, other: object) -> bool:
@@ -56,7 +53,46 @@ class UnsignedInteger:
         return f"<UnsignedInteger [value={self.value}]>"
 
 
-@type_checked
+class Float:
+    def __init__(self, value: float) -> None:
+        self.value = value
+
+    def pack(self, packer: Packer) -> None:
+        packer.pack_float(self.value)
+
+    @staticmethod
+    def unpack(unpacker: Unpacker) -> float:
+        return unpacker.unpack_float()
+
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, self.__class__):
+            return NotImplemented
+        return self.value == other.value
+
+    def __str__(self):
+        return f"<Float [value={self.value}]>"
+
+
+class Double:
+    def __init__(self, value: float) -> None:
+        self.value = value
+
+    def pack(self, packer: Packer) -> None:
+        packer.pack_double(self.value)
+
+    @staticmethod
+    def unpack(unpacker: Unpacker) -> float:
+        return unpacker.unpack_double()
+
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, self.__class__):
+            return NotImplemented
+        return self.value == other.value
+
+    def __str__(self):
+        return f"<Double [value={self.value}]>"
+
+
 class Hyper:
     def __init__(self, value: int) -> None:
         self.value = value
@@ -65,7 +101,7 @@ class Hyper:
         packer.pack_hyper(self.value)
 
     @staticmethod
-    def unpack(unpacker: Unpacker) -> "int":
+    def unpack(unpacker: Unpacker) -> int:
         return unpacker.unpack_hyper()
 
     def __eq__(self, other: object) -> bool:
@@ -77,7 +113,6 @@ class Hyper:
         return f"<Hyper [value={self.value}]>"
 
 
-@type_checked
 class UnsignedHyper:
     def __init__(self, value: int) -> None:
         self.value = value
@@ -86,7 +121,7 @@ class UnsignedHyper:
         packer.pack_uhyper(self.value)
 
     @staticmethod
-    def unpack(unpacker: Unpacker) -> "int":
+    def unpack(unpacker: Unpacker) -> int:
         return unpacker.unpack_uhyper()
 
     def __eq__(self, other: object) -> bool:
@@ -98,7 +133,6 @@ class UnsignedHyper:
         return f"<UnsignedHyper [value={self.value}]>"
 
 
-@type_checked
 class Boolean:
     def __init__(self, value: bool) -> None:
         self.value = value
@@ -107,7 +141,7 @@ class Boolean:
         packer.pack_bool(self.value)
 
     @staticmethod
-    def unpack(unpacker: Unpacker) -> "bool":
+    def unpack(unpacker: Unpacker) -> bool:
         return unpacker.unpack_bool()
 
     def __eq__(self, other: object) -> bool:
@@ -119,7 +153,6 @@ class Boolean:
         return f"<Boolean [value={self.value}]>"
 
 
-@type_checked
 class String:
     def __init__(self, value: bytes, size: int) -> None:
         if len(value) > size:
@@ -148,7 +181,6 @@ class String:
         return f"<String [value={self.value}, size={self.size}]>"
 
 
-@type_checked
 class Opaque:
     def __init__(self, value: bytes, size: int, fixed: bool) -> None:
         if fixed:
@@ -175,7 +207,7 @@ class Opaque:
         packer.pack_fopaque(size, self.value)
 
     @staticmethod
-    def unpack(unpacker: Unpacker, size: int, fixed: bool) -> "bytes":
+    def unpack(unpacker: Unpacker, size: int, fixed: bool) -> bytes:
         if not fixed:
             size = unpacker.unpack_uint()
         return unpacker.unpack_fopaque(size)
